@@ -329,7 +329,7 @@ p_netk_get_utf8_property (Window xwindow, Atom atom)
     if (err != Success || result != Success)
         return NULL;
 
-    if (type != utf8_string || format != 8 || nitems == 0)
+    if (type != utf8_string || format != 8 || nitems == 0 || !val)
     {
         if (val)
             XFree (val);
@@ -493,7 +493,7 @@ p_netk_get_utf8_list (Window xwindow, Atom atom)
                             &bytes_after, (guchar **)&val);
     err = p_netk_error_trap_pop ();
 
-    if (err != Success || result != Success)
+    if (err != Success || result != Success || !val)
         return NULL;
 
     if (type != utf8_string || format != 8 || nitems == 0)
